@@ -4,6 +4,8 @@
 #include <iostream>
 #include <string>
 #include <math.h>
+#include <Rmath.h>
+
 using namespace Rcpp ;
 using namespace Eigen;
 using namespace std;
@@ -164,7 +166,7 @@ SEXP rechercheZ_sparse_relax(SEXP X,SEXP Zi,SEXP Zj,SEXP Si,SEXP Sj,SEXP bic_vid
   //liste candidats (couples [i,j])
     if (imet_tirage[0]==0)//methode de changement de la ligne et de la colonne
     {
-      k=rand() % p;//on tire un numero aleatoire pour savoir quel est la ligne et la colonne de candidats
+      k=int(runif(0,p)[0]);//on tire un numero aleatoire pour savoir quel est la ligne et la colonne de candidats
       for(i=0;i<p;i++)
       {
         if(i!=k)//on ne veut pas avoir de 1 sur la diagonale
@@ -180,7 +182,7 @@ SEXP rechercheZ_sparse_relax(SEXP X,SEXP Zi,SEXP Zj,SEXP Si,SEXP Sj,SEXP bic_vid
     }
     else if (imet_tirage[0]==-1)//seulement la colonne
     {
-      k=rand() % p;
+      k=int(runif(0,p)[0]);
       for(i=0;i<p;i++)
       {
         if(i!=k)
@@ -195,8 +197,8 @@ SEXP rechercheZ_sparse_relax(SEXP X,SEXP Zi,SEXP Zj,SEXP Si,SEXP Sj,SEXP bic_vid
     {
       for(i=0;i<nbcand;i++)
       {
-        rand1=rand() % p;//nombres aleatoire pour avoir le numero de la ligne
-        rand2=rand() % p;//nombres aleatoire pour avoir le numero de la colonne
+        rand1=int(runif(0,p)[0]);//nombres aleatoire pour avoir le numero de la ligne
+        rand2=int(runif(0,p)[0]);//nombres aleatoire pour avoir le numero de la colonne
         if (rand1==rand2)//on ne veut pas de 1 sur la diagonale
         {
           if(rand1<p-1)
@@ -611,8 +613,8 @@ SEXP rechercheZ_sparse_relax(SEXP X,SEXP Zi,SEXP Zj,SEXP Si,SEXP Sj,SEXP bic_vid
           sumexp=sumexp+bicweight(v);
         }
         w=-1;//initialisation candidat choisi (il est a -1 car on va rajouter un "+1" avec le while)
-        ran=rand();
-        ran=ran/32767;
+        ran=runif(0,1)[0];
+        //ran=ran/32767;
         sumcum=0;
         while (ran>=sumcum)//choix du candidat
         { 
@@ -900,8 +902,8 @@ SEXP rechercheZ_sparse_relax(SEXP X,SEXP Zi,SEXP Zj,SEXP Si,SEXP Sj,SEXP bic_vid
       }
       
       w=-1;//initialisation candidat choisi (il est a -1 car on va rajouter un "+1" avec le while)
-      ran=rand();
-      ran=ran/32767;
+          ran=runif(0,1)[0];
+        //ran=ran/32767;
       sumcum=0;
       while (ran>=sumcum)//choix du candidat
       { 
